@@ -1,4 +1,4 @@
 from psend import functions
 
 if __name__ == "__main__":
-    functions.send_push_notification()
\ No newline at end of file
+    functions.main()
\ No newline at end of file
